@@ -1,12 +1,21 @@
 # %%
+from pathlib import Path
+
 from aind_mri_targeting import headframe_rotations as hr
 
 # %%
 # File paths constant across mice
-mri_path =r'Y:\ephys\persist\data\MRI\processed\750108\UW_2024_12_17\750108_100.nii.gz'#"/path/to/mri.nii.gz"
-seg_path = r'Y:\ephys\persist\data\MRI\processed\750108\UW_2024_12_17\750108_HeadframeHoles.seg.nrrd'#"/path/to/segmentation.seg.nrrd"
-lower_plane_file = r'Y:\ephys\persist\data\MRI\processed\750108\UW_2024_12_17\750108_LowerPlane.mrk.json'#"/path/to/lower_plane.mrk.json"
-output_path = r'Y:\ephys\persist\data\MRI\processed\750108\UW_2024_12_17'#"/path/to/output"  # If None, will write in cwd
+# mri_path = "/path/to/mri.nii.gz"
+# seg_path = "/path/to/segmentation.seg.nrrd"
+# lower_plane_file = "/path/to/lower_plane.mrk.json"
+# output_path = "/path/to/output"  # If None, will write in cwd
+
+mouse = "771433"
+base_path = Path(f"Y:/ephys/persist/data/MRI/processed/{mouse}")
+mri_path = base_path / f"{mouse}_100.nii.gz"
+seg_path = base_path / f"{mouse}_HeadframeHoles.seg.nrrd"
+lower_plane_file = base_path / f"{mouse}_LowerPlane.mrk.json"
+output_path = base_path
 
 # Optional
 mouse = None  # or string of mouse name
