@@ -3,6 +3,7 @@ from pathlib import Path
 
 import numpy as np
 import SimpleITK as sitk
+from aind_anatomical_utils import slicer as sf
 from aind_mri_utils import reticle_calibrations as rc
 from aind_mri_utils import rotations as rot
 from aind_mri_utils.chemical_shift import (
@@ -10,7 +11,6 @@ from aind_mri_utils.chemical_shift import (
     compute_chemical_shift,
 )
 from aind_mri_utils.file_io import simpleitk as mr_sitk
-from aind_mri_utils.file_io import slicer_files as sf
 from aind_mri_utils.planning import candidate_insertions
 
 # %%
@@ -21,9 +21,7 @@ if whoami == "galen":
     base_save_dir = Path("/home/galen.lynch/")
 elif whoami == "yoni":
     base_dir = Path("Y:/")
-    base_save_dir = Path(
-        "C:/Users/yoni.browning/OneDrive - Allen Institute/Desktop/"
-    )
+    base_save_dir = Path("C:/Users/yoni.browning/OneDrive - Allen Institute/Desktop/")
 else:
     raise ValueError("Who are you again?")
 
@@ -31,61 +29,41 @@ headframe_model_dir = base_dir / "ephys/persist/data/MRI/HeadframeModels/"
 probe_model_file = (
     headframe_model_dir / "dovetailtweezer_oneShank_centered_corrected.obj"
 )  # "modified_probe_holder.obj"
-annotations_path = base_dir / "ephys/persist/data/MRI/processed/{}/HF".format(
-    mouse
-)
+annotations_path = base_dir / "ephys/persist/data/MRI/processed/{}/HF".format(mouse)
 
 headframe_path = headframe_model_dir / "TenRunHeadframe.obj"
 holes_path = headframe_model_dir / "OneOff_HolesOnly.obj"
 
 
-implant_holes_path = str(
-    annotations_path / "{}_ImplantHoles.seg.nrrd".format(mouse)
-)
+implant_holes_path = str(annotations_path / "{}_ImplantHoles.seg.nrrd".format(mouse))
 
-image_path = str(
-    annotations_path / "{}_100.nii.gz".format(mouse)
-)  # '_100.nii.gz'))
+image_path = str(annotations_path / "{}_100.nii.gz".format(mouse))  # '_100.nii.gz'))
 labels_path = str(
     annotations_path / "{}_HeadframeHoles.seg.nrrd".format(mouse)
 )  # 'Segmentation.seg.nrrd')#
-brain_mask_path = str(
-    annotations_path / ("{}_auto_skull_strip.nrrd".format(mouse))
-)
-manual_annotation_path = str(
-    annotations_path / (f"{mouse}_ManualAnnotations.fcsv")
-)
+brain_mask_path = str(annotations_path / ("{}_auto_skull_strip.nrrd".format(mouse)))
+manual_annotation_path = str(annotations_path / (f"{mouse}_ManualAnnotations.fcsv"))
 cone_path = (
     base_dir
     / "ephys/persist/Software/PinpointBuilds/WavefrontFiles/Cone_0160-200-53.obj"  # noqa E501
 )
 
-uw_yoni_annotation_path = (
-    annotations_path / f"targets-{mouse}-transformed.fcsv"
-)
+uw_yoni_annotation_path = annotations_path / f"targets-{mouse}-transformed.fcsv"
 
 newscale_file_name = headframe_path / "Centered_Newscale_2pt0.obj"
 #
 
 
 calibration_filename = "calibration_info_np2_2024_08_13T09_57_00.xlsx"
-calibration_dir = (
-    base_dir / "ephys/persist/data/probe_calibrations/CSVCalibrations/"
-)
+calibration_dir = base_dir / "ephys/persist/data/probe_calibrations/CSVCalibrations/"
 calibration_file = calibration_dir / calibration_filename
-measured_hole_centers = (
-    annotations_path / "measured_hole_centers_conflict.xlsx"
-)
+measured_hole_centers = annotations_path / "measured_hole_centers_conflict.xlsx"
 
 
 # manual_hole_centers_file = annotations_path / 'hole_centers.mrk.json'
 
-transformed_targets_save_path = annotations_path / (
-    mouse + "TransformedTargets.csv"
-)
-test_probe_translation_save_path = str(
-    base_save_dir / "test_probe_translation.h5"
-)
+transformed_targets_save_path = annotations_path / (mouse + "TransformedTargets.csv")
+test_probe_translation_save_path = str(base_save_dir / "test_probe_translation.h5")
 transform_filename = str(annotations_path / (mouse + "_com_plane.h5"))
 
 # %%
@@ -134,12 +112,10 @@ for probe in measurements:
             find_scaling=True,
         )
     else:
-        transform_rs[probe], transform_offsets[probe], _ = (
-            rc.fit_rotation_params(
-                reticle_pts=reticle_coords,
-                probe_pts=probe_coords,
-                find_scaling=False,
-            )
+        transform_rs[probe], transform_offsets[probe], _ = rc.fit_rotation_params(
+            reticle_pts=reticle_coords,
+            probe_pts=probe_coords,
+            find_scaling=False,
         )
         scaling_vecs[probe] = None
 
@@ -157,9 +133,9 @@ for probe in measurements:
 # %%
 manual_annotation = sf.read_slicer_fcsv(manual_annotation_path)
 image = sitk.ReadImage(image_path)
-trans = mr_sitk.load_sitk_transform(
-    transform_filename, homogeneous=True, invert=True
-)[0]
+trans = mr_sitk.load_sitk_transform(transform_filename, homogeneous=True, invert=True)[
+    0
+]
 
 
 # %%
